@@ -1,7 +1,6 @@
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/gnome-config.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-client.h>
@@ -9,7 +8,6 @@
 #include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomeui/gnome-app-helper.h>
 #include <gconf/gconf-client.h>
-#include "util.h"
 #include "eog-window.h"
 #include "eog-thumbnail.h"
 #include "session.h"
@@ -36,6 +34,7 @@ typedef struct {
 #ifdef G_OS_WIN32
 
 #include <windows.h>
+#include "util.h"
 
 static const char *
 get_installation_subdir (const char *configure_time_path)
@@ -105,19 +104,6 @@ eog_get_localedir (void)
 #endif	/* G_OS_WIN32 */
 
 
-static void 
-free_uri_list (GList *list)
-{
-	GList *it;
-	
-	for (it = list; it != NULL; it = it->next) {
-		gnome_vfs_uri_unref ((GnomeVFSURI*)it->data);
-	}
-
-	if (list != NULL) 
-		g_list_free (list);
-}
-
 static void 
 free_string_list (GList *list)
 {
@@ -136,7 +122,7 @@ load_context_free (LoadContext *ctx)
 {
 	if (ctx == NULL) return;
 
-	free_uri_list (ctx->uri_list);
+	gnome_vfs_uri_list_free (ctx->uri_list);
 	if (ctx->img_list != NULL)
 			g_object_unref (ctx->img_list);
 	ctx->img_list = NULL;
